sdv.metrics.tabular.KSComplement
==========================

.. currentmodule:: sdv.metrics.tabular

.. autoclass:: KSComplement

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~KSComplement.__init__
      ~KSComplement.compute
      ~KSComplement.get_subclasses
      ~KSComplement.normalize
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~KSComplement.field_types
      ~KSComplement.goal
      ~KSComplement.max_value
      ~KSComplement.min_value
      ~KSComplement.name
      ~KSComplement.single_column_metric_kwargs
   
   